@@ -53,7 +53,7 @@ const QHash<QString, ColorFlags> Configuration::relevantThemes
 static const QString DEFAULT_LIGHT_COLOR_THEME = "iaito";
 static const QString DEFAULT_DARK_COLOR_THEME = "ayu";
 
-const QHash<QString, QHash<ColorFlags, QColor>> Configuration::cutterOptionColors
+const QHash<QString, QHash<ColorFlags, QColor>> Configuration::iaitoOptionColors
     = {{"gui.cflow", {{DarkFlag, QColor(0xff, 0xff, 0xff)}, {LightFlag, QColor(0x00, 0x00, 0x00)}}},
        {"gui.dataoffset",
         {{DarkFlag, QColor(0xff, 0xff, 0xff)}, {LightFlag, QColor(0x00, 0x00, 0x00)}}},
@@ -114,7 +114,6 @@ Configuration *Configuration::mPtr = nullptr;
 static const QHash<QString, QVariant> asmOptions
     = {{"asm.esil", false},
        {"asm.pseudo", false},
-       {"asm.offset", true},
        {"asm.xrefs", false},
        {"asm.indent", false},
        {"asm.describe", false},
@@ -143,10 +142,19 @@ static const QHash<QString, QVariant> asmOptions
        {"asm.marks", false},
        {"asm.refptr", false},
        {"asm.flags.real", true},
-       {"asm.offset.relative", false},
-       {"asm.offset.flags", false},
        {"esil.breakoninvalid", false},
-       {"graph.offset", false}};
+#if R2_VERSION_NUMBER >= 50909
+       {"graph.addr", true},
+       {"asm.addr", true},
+       {"asm.addr.relto", ""},
+       {"asm.flags.addr", false}
+#else
+       {"graph.offset", true},
+       {"asm.offset", true},
+       {"asm.offset.relative", false},
+       {"asm.offset.flags", false}
+#endif
+};
 
 Configuration::Configuration()
     : QObject()
@@ -444,12 +452,12 @@ QString Configuration::getLastThemeOf(const IaitoInterfaceTheme &currInterfaceTh
 
 void Configuration::setInterfaceTheme(int theme)
 {
-    if (theme >= cutterInterfaceThemesList().size() || theme < 0) {
+    if (theme >= iaitoInterfaceThemesList().size() || theme < 0) {
         theme = 0;
     }
     s.setValue("ColorPalette", theme);
 
-    IaitoInterfaceTheme interfaceTheme = cutterInterfaceThemesList()[theme];
+    IaitoInterfaceTheme interfaceTheme = iaitoInterfaceThemesList()[theme];
 
     if (interfaceTheme.name == "Native") {
         loadNativeStylesheet();
@@ -463,7 +471,7 @@ void Configuration::setInterfaceTheme(int theme)
         loadNativeStylesheet();
     }
 
-    for (auto it = cutterOptionColors.cbegin(); it != cutterOptionColors.cend(); it++) {
+    for (auto it = iaitoOptionColors.cbegin(); it != iaitoOptionColors.cend(); it++) {
         setColor(it.key(), it.value()[interfaceTheme.flag]);
     }
 
@@ -479,11 +487,11 @@ void Configuration::setInterfaceTheme(int theme)
 const IaitoInterfaceTheme *Configuration::getCurrentTheme()
 {
     int i = getInterfaceTheme();
-    if (i < 0 || i >= cutterInterfaceThemesList().size()) {
+    if (i < 0 || i >= iaitoInterfaceThemesList().size()) {
         i = 0;
         setInterfaceTheme(i);
     }
-    return &cutterInterfaceThemesList()[i];
+    return &iaitoInterfaceThemesList()[i];
 }
 
 #ifdef IAITO_ENABLE_KSYNTAXHIGHLIGHTING
@@ -521,7 +529,8 @@ QSyntaxHighlighter *Configuration::createSyntaxHighlighter(QTextDocument *docume
 
 QString Configuration::getLogoFile()
 {
-    return windowColorIsDark() ? QString(":/img/iaito-o-light.svg") : QString(":/img/iaito-o.svg");
+    return windowColorIsDark() ? QStringLiteral(":/img/iaito-o-light.svg")
+                               : QStringLiteral(":/img/iaito-o.svg");
 }
 
 /**
@@ -605,7 +614,7 @@ void Configuration::applySavedAsmOptions()
     }
 }
 
-const QList<IaitoInterfaceTheme> &Configuration::cutterInterfaceThemesList()
+const QList<IaitoInterfaceTheme> &Configuration::iaitoInterfaceThemesList()
 {
     static const QList<IaitoInterfaceTheme> list
         = {{"Native", Configuration::nativeWindowIsDark() ? DarkFlag : LightFlag},
