@@ -3,6 +3,7 @@
 
 // Common Headers
 #include "IaitoApplication.h"
+#include "common/AnalTask.h"
 #include "common/BugReporting.h"
 #include "common/Helpers.h"
 #include "common/ProgressIndicator.h"
@@ -15,22 +16,25 @@
 #include "dialogs/AboutDialog.h"
 #include "dialogs/AsyncTaskDialog.h"
 #include "dialogs/CommentsDialog.h"
+#include "dialogs/FortuneDialog.h"
 #include "dialogs/InitialOptionsDialog.h"
 #include "dialogs/LayoutManager.h"
-#include "dialogs/FortuneDialog.h"
 #include "dialogs/MapFileDialog.h"
 #include "dialogs/NewFileDialog.h"
+#include "dialogs/PackageManagerDialog.h"
 #include "dialogs/SaveProjectDialog.h"
 #include "dialogs/WelcomeDialog.h"
 #include "dialogs/preferences/PreferencesDialog.h"
 
 // Widgets Headers
 #include "widgets/BacktraceWidget.h"
+#include "widgets/BinariesWidget.h"
 #include "widgets/BreakpointWidget.h"
 #include "widgets/CallGraph.h"
 #include "widgets/ClassesWidget.h"
 #include "widgets/CommentsWidget.h"
 #include "widgets/ConsoleWidget.h"
+#include "widgets/CustomCommandWidget.h"
 #include "widgets/Dashboard.h"
 #include "widgets/DebugActions.h"
 #include "widgets/DecompilerWidget.h"
@@ -38,6 +42,7 @@
 #include "widgets/DisassemblyWidget.h"
 #include "widgets/EntrypointWidget.h"
 #include "widgets/ExportsWidget.h"
+#include "widgets/FilesWidget.h"
 #include "widgets/FlagsWidget.h"
 #include "widgets/FunctionsWidget.h"
 #include "widgets/GraphView.h"
@@ -45,10 +50,12 @@
 #include "widgets/HeadersWidget.h"
 #include "widgets/HexdumpWidget.h"
 #include "widgets/ImportsWidget.h"
+#include "widgets/MapsWidget.h"
 #include "widgets/MemoryMapWidget.h"
 #include "widgets/Omnibar.h"
 #include "widgets/OverviewWidget.h"
 #include "widgets/ProcessesWidget.h"
+#include "widgets/R2AIWidget.h"
 #include "widgets/R2GraphWidget.h"
 #include "widgets/RegisterRefsWidget.h"
 #include "widgets/RegistersWidget.h"
@@ -91,6 +98,7 @@
 #include <QPropertyAnimation>
 #include <QSysInfo>
 
+#include <QKeyEvent>
 #include <QScrollBar>
 #include <QSettings>
 #include <QShortcut>
@@ -99,6 +107,7 @@
 #include <QStyledItemDelegate>
 #include <QSvgRenderer>
 #include <QTextCursor>
+#include <QTimer>
 #include <QToolButton>
 #include <QToolTip>
 #include <QTreeWidgetItem>
@@ -115,6 +124,15 @@ T *getNewInstance(MainWindow *m)
     return new T(m);
 }
 
+void MainWindow::updateStatusBar(RVA addr, const QString &name)
+{
+    QString msg = RAddressString(addr);
+    if (!name.isEmpty()) {
+        msg += " " + name;
+    }
+    statusBar()->showMessage(msg);
+}
+
 using namespace Iaito;
 
 MainWindow::MainWindow(QWidget *parent)
@@ -133,6 +151,10 @@ MainWindow::~MainWindow() {}
 void MainWindow::initUI()
 {
     ui->setupUi(this);
+    // always show the main window status bar
+    statusBar()->show();
+    // Install event filter to catch function key releases
+    qApp->installEventFilter(this);
 
     // Initialize context menu extensions for plugins
     disassemblyContextMenuExtensions = new QMenu(tr("Plugins"), this);
@@ -142,6 +164,7 @@ void MainWindow::initUI()
     connect(ui->actionExtraGraph, &QAction::triggered, this, &MainWindow::addExtraGraph);
     connect(ui->actionExtraDisassembly, &QAction::triggered, this, &MainWindow::addExtraDisassembly);
     connect(ui->actionExtraHexdump, &QAction::triggered, this, &MainWindow::addExtraHexdump);
+    connect(ui->actionAddCustomCommand, &QAction::triggered, this, &MainWindow::addExtraCustomCommand);
     connect(ui->actionCommitChanges, &QAction::triggered, this, []() {
         Core()->commitWriteCache();
     });
@@ -250,15 +273,23 @@ void MainWindow::initUI()
     for (auto &plugin : plugins) {
         plugin->setupInterface(this);
     }
+    // Add r2ai dock widget as plugin
+    {
+        R2AIWidget *r2aiDock = new R2AIWidget(this);
+        addPluginDockWidget(r2aiDock);
+    }
 
     // Check if plugins are loaded and display tooltips accordingly
     ui->menuWindows->setToolTipsVisible(true);
-    if (plugins.empty()) {
+    // Only disable the Plugins menu when no IAito plugins AND no dock widgets added
+    bool hasIaitoPlugins = !plugins.empty();
+    bool hasDockEntries = !ui->menuPlugins->actions().isEmpty();
+    if (!hasIaitoPlugins && !hasDockEntries) {
         ui->menuPlugins->menuAction()->setToolTip(
-            tr("No plugins are installed. Check the plugins section on Iaito "
+            tr("No plugins installed. Check the plugins section on Iaito "
                "documentation to learn more."));
         ui->menuPlugins->setEnabled(false);
-    } else if (ui->menuPlugins->isEmpty()) {
+    } else if (!hasDockEntries) {
         ui->menuPlugins->menuAction()->setToolTip(
             tr("The installed plugins didn't add entries to this menu."));
         ui->menuPlugins->setEnabled(false);
@@ -393,6 +424,10 @@ void MainWindow::initDocks()
            breakpointDock = new BreakpointWidget(this),
            registerRefsDock = new RegisterRefsWidget(this)};
 
+    QList<IaitoDockWidget *> ioDocks
+        = {filesDock = new FilesWidget(this),
+           binariesDock = new BinariesWidget(this),
+           mapsDock = new MapsWidget(this)};
     QList<IaitoDockWidget *> infoDocks = {
         classesDock = new ClassesWidget(this),
         entrypointDock = new EntrypointWidget(this),
@@ -446,6 +481,7 @@ void MainWindow::initDocks()
     };
     ui->menuWindows->addActions(makeActionList(windowDocks2));
     ui->menuAddInfoWidgets->addActions(makeActionList(infoDocks));
+    ui->menuAddIoWidgets->addActions(makeActionList(ioDocks));
     ui->menuAddDebugWidgets->addActions(makeActionList(debugDocks));
 
     auto uniqueDocks = windowDocks + windowDocks2 + infoDocks + debugDocks;
@@ -496,6 +532,12 @@ void MainWindow::addExtraDecompiler()
     addExtraWidget(extraDock);
 }
 
+void MainWindow::addExtraCustomCommand()
+{
+    auto *extraDock = new CustomCommandWidget(this);
+    addExtraWidget(extraDock);
+}
+
 void MainWindow::addExtraWidget(IaitoDockWidget *extraDock)
 {
     extraDock->setTransient(true);
@@ -542,6 +584,7 @@ void MainWindow::addMenuFileAction(QAction *action)
 
 void MainWindow::openCurrentCore(InitialOptions &options, bool skipOptionsDialog)
 {
+    Q_UNUSED(skipOptionsDialog);
     RCore *core = iaitoPluginCore();
     if (core == nullptr) {
         return;
@@ -561,7 +604,7 @@ void MainWindow::openNewFile(InitialOptions &options, bool skipOptionsDialog)
 
     /* Prompt to load filename.r2 script */
     if (options.script.isEmpty()) {
-        QString script = QString("%1.r2").arg(this->filename);
+        QString script = QStringLiteral("%1.r2").arg(this->filename);
         if (r_file_exists(script.toStdString().data())) {
             QMessageBox mb;
             mb.setWindowTitle(tr("Script loading"));
@@ -695,6 +738,30 @@ void MainWindow::finalizeOpen()
         }
     }
     consoleDock->show();
+    // Wire up status bar updates for all seekable views
+    // Disassembly widgets
+    for (auto disasm : findChildren<DisassemblyWidget *>()) {
+        if (auto sk = disasm->getSeekable()) {
+            connect(sk, &IaitoSeekable::seekableSeekChanged, this, [this](RVA addr) {
+                updateStatusBar(addr);
+            });
+        }
+    }
+    // Graph widgets
+    for (auto graphDock : findChildren<GraphWidget *>()) {
+        // Seekable for graph
+        if (auto sk = graphDock->getSeekable()) {
+            connect(sk, &IaitoSeekable::seekableSeekChanged, this, [this](RVA addr) {
+                updateStatusBar(addr);
+            });
+        }
+        // Graph name changes (e.g., function)
+        if (auto dg = qobject_cast<DisassemblerGraphView *>(graphDock->getGraphView())) {
+            connect(dg, &DisassemblerGraphView::nameChanged, this, [this, dg](const QString &name) {
+                updateStatusBar(dg->currentFcnAddr, name);
+            });
+        }
+    }
 }
 
 bool MainWindow::saveProject(bool quit)
@@ -898,6 +965,9 @@ void MainWindow::restoreDocks()
     tabifyDockWidget(dashboardDock, r2GraphDock);
     tabifyDockWidget(dashboardDock, callGraphDock);
     tabifyDockWidget(dashboardDock, globalCallGraphDock);
+    tabifyDockWidget(dashboardDock, mapsDock);
+    tabifyDockWidget(dashboardDock, filesDock);
+    tabifyDockWidget(dashboardDock, binariesDock);
     for (const auto &it : dockWidgets) {
         // Check whether or not current widgets is graph, hexdump or disasm
         if (isExtraMemoryWidget(it)) {
@@ -1137,14 +1207,14 @@ void MainWindow::updateHistoryMenu(QMenu *menu, bool redo)
         if (history != redo || current) { // Include current in both directions
             QString addressString = RAddressString(offset);
 
-            QString toolTip
-                = QString("%1 %2").arg(addressString, name); // show non truncated name in tooltip
+            QString toolTip = QStringLiteral("%1 %2")
+                                  .arg(addressString, name); // show non truncated name in tooltip
 
             name.truncate(MAX_NAME_LENGTH); // TODO:#1904 use common name
                                             // shortening function
-            QString label = QString("%1 (%2)").arg(name, addressString);
+            QString label = QStringLiteral("%1 (%2)").arg(name, addressString);
             if (current) {
-                label = QString("current position (%1)").arg(addressString);
+                label = QStringLiteral("current position (%1)").arg(addressString);
             }
             QAction *action = new QAction(label, menu);
             action->setToolTip(toolTip);
@@ -1345,8 +1415,8 @@ IaitoLayout MainWindow::getViewLayout()
 
     for (auto dock : dockWidgets) {
         QVariantMap properties;
-        if (auto cutterDock = qobject_cast<IaitoDockWidget *>(dock)) {
-            properties = cutterDock->serializeViewProprties();
+        if (auto iaitoDock = qobject_cast<IaitoDockWidget *>(dock)) {
+            properties = iaitoDock->serializeViewProprties();
         }
         layout.viewProperties.insert(dock->objectName(), std::move(properties));
     }
@@ -1635,6 +1705,18 @@ void MainWindow::on_actionIssue_triggered()
     openIssue();
 }
 
+void MainWindow::on_actionR2pm_triggered()
+{
+    PackageManagerDialog dlg(this);
+    dlg.exec();
+}
+// Launch via Preferences menu
+void MainWindow::on_actionPackageManagerPrefs_triggered()
+{
+    PackageManagerDialog dlg(this);
+    dlg.exec();
+}
+
 void MainWindow::websiteClicked()
 {
     QDesktopServices::openUrl(QUrl("https://www.radare.org"));
@@ -1822,8 +1904,28 @@ void MainWindow::mousePressEvent(QMouseEvent *event)
     }
 }
 
-bool MainWindow::eventFilter(QObject *, QEvent *event)
+bool MainWindow::eventFilter(QObject *watched, QEvent *event)
 {
+    if (event->type() == QEvent::KeyRelease) {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        int key = keyEvent->key();
+        if (key >= Qt::Key_F1 && key <= Qt::Key_F12) {
+            QTimer::singleShot(0, this, &MainWindow::refreshAll);
+        }
+    }
+    if (event->type() == QEvent::KeyPress) {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        int key = keyEvent->key();
+        if (key >= Qt::Key_F1 && key <= Qt::Key_F12) {
+            int idx = key - Qt::Key_F1 + 1;
+            QString configKey = QStringLiteral("key.f%1").arg(idx);
+            QString cmd = core->getConfig(configKey);
+            if (!cmd.isEmpty()) {
+                core->cmd(cmd);
+                return true;
+            }
+        }
+    }
     if (event->type() == QEvent::MouseButtonPress) {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
         if (mouseEvent->button() == Qt::ForwardButton || mouseEvent->button() == Qt::BackButton) {
@@ -1831,7 +1933,7 @@ bool MainWindow::eventFilter(QObject *, QEvent *event)
             return true;
         }
     }
-    return false;
+    return QMainWindow::eventFilter(watched, event);
 }
 
 bool MainWindow::event(QEvent *event)
