@@ -11,8 +11,10 @@
 #include "common/TempConfig.h"
 #include "core/MainWindow.h"
 
+#include "dialogs/ShortcutKeysDialog.h"
 #include <QAbstractSlider>
 #include <QClipboard>
+#include <QKeyEvent>
 #include <QObject>
 #include <QPlainTextEdit>
 #include <QScrollBar>
@@ -39,8 +41,9 @@ DecompilerWidget::DecompilerWidget(MainWindow *main)
     updateWindowTitle();
 
     setHighlighter(Config()->isDecompilerAnnotationHighlighterEnabled());
-    // Event filter to intercept double click and right click in the textbox
+    // Event filter to intercept key, mouse double click, and right click in the textbox
     ui->textEdit->viewport()->installEventFilter(this);
+    ui->textEdit->installEventFilter(this);
 
     setupFonts();
     colorsUpdatedSlot();
@@ -124,7 +127,7 @@ Decompiler *DecompilerWidget::getCurrentDecompiler()
 
 ut64 DecompilerWidget::offsetForPosition(size_t pos)
 {
-    size_t closestPos = SIZE_MAX;
+    ut64 closestPos = UT64_MAX;
     ut64 closestOffset = mCtxMenu->getFirstOffsetInLine();
     void *iter;
     r_vector_foreach(&code->annotations, iter)
@@ -134,18 +137,22 @@ ut64 DecompilerWidget::offsetForPosition(size_t pos)
             || annotation->end <= pos) {
             continue;
         }
-        if (closestPos != SIZE_MAX && closestPos >= annotation->start) {
+        if (closestPos != UT64_MAX && closestPos >= annotation->start) {
             continue;
         }
         closestPos = annotation->start;
         closestOffset = annotation->offset.offset;
     }
+    // eprintf ("%llx \n", closestOffset);
+    if (closestOffset != UT64_MAX) {
+        this->currentOffset = closestOffset;
+    }
     return closestOffset;
 }
 
 size_t DecompilerWidget::positionForOffset(ut64 offset)
 {
-    size_t closestPos = SIZE_MAX;
+    ut64 closestPos = UT64_MAX;
     ut64 closestOffset = UT64_MAX;
     void *iter;
     r_vector_foreach(&code->annotations, iter)
@@ -292,7 +299,7 @@ void DecompilerWidget::refreshDecompiler()
 QTextCursor DecompilerWidget::getCursorForAddress(RVA addr)
 {
     size_t pos = positionForOffset(addr);
-    if (pos == SIZE_MAX || pos == 0) {
+    if (pos == UT64_MAX || pos == 0) {
         return QTextCursor();
     }
     QTextCursor cursor = ui->textEdit->textCursor();
@@ -429,7 +436,7 @@ void DecompilerWidget::updateCursorPosition()
 {
     RVA offset = seekable->getOffset();
     size_t pos = positionForOffset(offset);
-    if (pos == SIZE_MAX) {
+    if (pos == UT64_MAX) {
         return;
     }
     mCtxMenu->setOffset(offset);
@@ -504,6 +511,33 @@ void DecompilerWidget::seekToReference()
 
 bool DecompilerWidget::eventFilter(QObject *obj, QEvent *event)
 {
+    // Handle Vim-like mark and jump in decompiler view
+    if (event->type() == QEvent::KeyPress
+        && (obj == ui->textEdit || obj == ui->textEdit->viewport())) {
+        QKeyEvent *keyEvent = static_cast<QKeyEvent *>(event);
+        if (keyEvent->modifiers() == Qt::NoModifier && keyEvent->key() == Qt::Key_M) {
+            // Prepare context and compute offset for current decompiler line
+            size_t pos = ui->textEdit->textCursor().position();
+            setAnnotationsAtCursor(pos);
+            setInfoForBreakpoints();
+            ut64 offset = offsetForPosition(pos);
+            if (offset == UT64_MAX) {
+                offset = this->currentOffset;
+            }
+            mCtxMenu->setOffset(offset);
+            ShortcutKeysDialog dlg(ShortcutKeysDialog::SetMark, offset, this);
+            dlg.exec();
+            return true;
+        } else if (keyEvent->modifiers() == Qt::NoModifier && keyEvent->key() == Qt::Key_Apostrophe) {
+            ShortcutKeysDialog dlg(ShortcutKeysDialog::JumpTo, RVA_INVALID, this);
+            if (dlg.exec() == QDialog::Accepted) {
+                QChar key = dlg.selectedKey();
+                RVA addr = ShortcutKeys::instance()->getMark(key);
+                seekable->seek(addr);
+            }
+            return true;
+        }
+    }
     if (event->type() == QEvent::MouseButtonDblClick
         && (obj == ui->textEdit || obj == ui->textEdit->viewport())) {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
@@ -516,6 +550,8 @@ bool DecompilerWidget::eventFilter(QObject *obj, QEvent *event)
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
         if (mouseEvent->button() == Qt::RightButton && !ui->textEdit->textCursor().hasSelection()) {
             ui->textEdit->setTextCursor(ui->textEdit->cursorForPosition(mouseEvent->pos()));
+            size_t pos = ui->textEdit->textCursor().position();
+            this->currentOffset = offsetForPosition(pos);
             return true;
         }
     }
